--
-- SampleModMap
--
-- @author  Christian Ammann
-- @date  24/10/11
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

SampleModMap = {}

local SampleModMap_mt = Class(SampleModMap, Mission00);

function SampleModMap:new(baseDirectory, customMt)
    local mt = customMt;
    if mt == nil then
        mt = SampleModMap_mt;
    end;
    local self = SampleModMap:superClass():new(baseDirectory, mt);
    return self;
end;

function SampleModMap:delete()
    SampleModMap:superClass().delete(self);
end;

function SampleModMap:load()
	self.environment = Environment:new(Utils.getFilename("$data/sky/sky_day_night.i3d", self.baseDirectory), true, 8, true, true);
	
	self.skiResortBase = nil;
	self.hotelBase = nil;
	self.helpIconsBase = nil;
	self.facilitySlotObjectList = {};
	self.stationObjectList = {};
	self.collectableGnomesObject = nil;
	self.icicleBase = nil;
	self.saltDepotPDAHotspots = {};
	
	self:loadMap(Utils.getFilename("map01.i3d", self.baseDirectory));
	self.missionPDA:loadMap(Utils.getFilename("map01/pda_map.png", self.baseDirectory));

    g_inGameMenu:setSlopeMap(Utils.getFilename("map01/slopeMap.png", self.baseDirectory));
    g_inGameMenu:setStationMap(Utils.getFilename("map01/stationMap.png", self.baseDirectory));
    g_inGameMenu:setHotelMap(Utils.getFilename("map01/hotelMap.png", self.baseDirectory));

    local iconSize = self.missionPDA.pdaMapWidth / 15;
    -- ATMs
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 1024 + 25.5, 1024 + 633.75, iconSize, iconSize * (4 / 3), false, false, 0);
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 1024 - 360.15, 1024 + 558.5, iconSize, iconSize * (4 / 3), false, false, 0);
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 1024 - 649.20, 1024 + 594.22, iconSize, iconSize * (4 / 3), false, false, 0);
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 1024 - 71.95, 1024 + 544.1, iconSize, iconSize * (4 / 3), false, false, 0);
    self.missionPDA:createMapHotspot("Bank", Utils.getFilename("$dataS2/missions/hud_pda_spot_bank.png", self.baseDirectory), 1024 + 652.83, 1024 + 497.1, iconSize, iconSize * (4 / 3), false, false, 0);
    -- salt depots
    self.saltDepotPDAHotspots[1] = self.missionPDA:createMapHotspot("Salt Depot", Utils.getFilename("$dataS2/missions/hud_pda_spot_saltDepot.png", self.baseDirectory), 1024 - 240.5, 1024 + 610, iconSize, iconSize * (4 / 3), false, false, 0);
    self.saltDepotPDAHotspots[2] = self.missionPDA:createMapHotspot("Salt Depot", Utils.getFilename("$dataS2/missions/hud_pda_spot_saltDepot.png", self.baseDirectory), 1024 + 289.3, 1024 + 688.4, iconSize, iconSize * (4 / 3), false, false, 0);
    -- shop icon
    self.missionPDA:createMapHotspot("Shop", Utils.getFilename("$dataS2/missions/hud_pda_spot_shop.png", self.baseDirectory), 1024 + 10, 1024 + 636, iconSize, iconSize * (4 / 3), false, false, 0);


    self:loadMap(Utils.getFilename("map01/paths/trafficPaths.i3d", self.baseDirectory));
    self.skiResortManager = SkiResortManager:new();
    self.skiResortManager:load(Utils.getFilename("skiResort_map01.xml", self.baseDirectory), Utils.getFilename("skiSlopes_map01.xml", self.baseDirectory), Utils.getFilename("hotels_map01.xml", self.baseDirectory));

    SampleModMap:superClass().load(self);


    self.environment:addDayChangeListener(self.skiResortManager);
    self.environment:addHourChangeListener(self.skiResortManager);
    self.environment:addMinuteChangeListener(self.skiResortManager);

    self.skiResortManager:putIconsOnPDAMap();

    if not self.missionDynamicInfo.isMultiplayer then
        self:updateFoundGnomes();
        self:updateFoundHelpIcons();
    else
        self:removeAllGnomes();
        self:removeAllHelpIcons();
        if self.icicleBase ~= nil then self.icicleBase:removeAllIcicles(); end;
    end;

    self.ingameMissionManager:setMissionInterval(self.missionStats.missionFrequency);
end;

function SampleModMap:loadFinished()
    SampleModMap:superClass().loadFinished(self);
end;

function SampleModMap:mouseEvent(posX, posY, isDown, isUp, button)
    SampleModMap:superClass().mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function SampleModMap:keyEvent(unicode, sym, modifier, isDown)
    SampleModMap:superClass().keyEvent(self, unicode, sym, modifier, isDown);
end;

function SampleModMap:update(dt)
    SampleModMap:superClass().update(self, dt);
    self.skiResortManager:update(dt); -- this runs the actual simulation of the game's ecosystem
end;

function SampleModMap:draw()
    SampleModMap:superClass().draw(self);
end;
